@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2010 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2011 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -141,6 +141,7 @@ void add_user(struct w *widgets)
     int found_server=0, standard_server=0;
     gchar *utf8=NULL;
     gchar *info, *cmd, *restricted_dir=NULL;
+    gint active_index = 0;
 
     G_CONST_RETURN gchar *username;
     G_CONST_RETURN gchar *password;
@@ -564,20 +565,25 @@ void add_user(struct w *widgets)
     strcat(user_profile, "DisplayLogin welcome.msg\n");
     strcat(user_profile, "DisplayChdir .msg\n");
       
-    /* Ratio Module (reversed br/fr order in the gui) */
+    /* Ratio Module has been found (reversed br/fr order in the gui) */
     if( use_ratio )
     {
-        strcat(user_profile, "UserRatio ");
-        strcat(user_profile, username);
-        strcat(user_profile, " ");
-        strcat(user_profile, fr);
-        strcat(user_profile, " ");
-        strcat(user_profile, frc);
-        strcat(user_profile, " ");
-        strcat(user_profile, br);
-        strcat(user_profile, " ");
-	strcat(user_profile, brc);
-        strcat(user_profile, "\n");
+	/* Ratios have been turned on in the global settings */
+	active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[16]));
+	if( active_index == 0 )
+	{	
+    	    strcat(user_profile, "UserRatio ");
+    	    strcat(user_profile, username);
+    	    strcat(user_profile, " ");
+    	    strcat(user_profile, fr);
+    	    strcat(user_profile, " ");
+    	    strcat(user_profile, frc);
+    	    strcat(user_profile, " ");
+    	    strcat(user_profile, br);
+    	    strcat(user_profile, " ");
+	    strcat(user_profile, brc);
+    	    strcat(user_profile, "\n");
+	}
     }
 
     /* Logins from, if nothing is specified we allow everything */
