@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2010 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2011 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -180,6 +180,7 @@ void apply_user(struct w *widgets)
     int found = 0;
     gchar *UserUsername;
     char *temp_user;
+    gint active_index = 0;
 
     G_CONST_RETURN gchar *username;
     G_CONST_RETURN gchar *groupname;
@@ -285,17 +286,23 @@ void apply_user(struct w *widgets)
     /* Ratio Module (reversed br/fr order in the gui) */
     if( use_ratio )
     {
-	strcat(user_profile, "UserRatio ");
-	strcat(user_profile, username);
-	strcat(user_profile, " ");
-	strcat(user_profile, fr);
-	strcat(user_profile, " ");
-	strcat(user_profile, frc);
-	strcat(user_profile, " ");
-	strcat(user_profile, br);
-	strcat(user_profile, " ");
-	strcat(user_profile, brc);
-	strcat(user_profile, "\n");
+	/* Ratios have been turned on in the global settings */
+	active_index = gtk_combo_box_get_active(GTK_COMBO_BOX(widgets->server_set_combo[16]));
+	if( active_index == 0 )
+	{	
+
+	    strcat(user_profile, "UserRatio ");
+	    strcat(user_profile, username);
+	    strcat(user_profile, " ");
+	    strcat(user_profile, fr);
+	    strcat(user_profile, " ");
+	    strcat(user_profile, frc);
+	    strcat(user_profile, " ");
+	    strcat(user_profile, br);
+	    strcat(user_profile, " ");
+	    strcat(user_profile, brc);
+	    strcat(user_profile, "\n");
+	}
     }
 
     /* Logins from, if nothing is specified we allow everything */
