@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2010 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2011 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -175,7 +175,7 @@ void create_main_window(struct w *widgets)
     info = g_strdup_printf(_("About"));
     utf8 = g_locale_to_utf8(info, strlen(info), NULL, NULL, NULL);
     g_free(info);
-    GtkWidget *toolbar_icon_about = gtk_image_new_from_stock("gtk-justify-center",
+    GtkWidget *toolbar_icon_about = gtk_image_new_from_stock("gtk-about",
                                       gtk_toolbar_get_icon_size(GTK_TOOLBAR(main_toolbar)));
     GtkWidget *about_button = gtk_toolbar_append_element(GTK_TOOLBAR(main_toolbar),
                                                           GTK_TOOLBAR_CHILD_BUTTON,
