@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - GProStats - Statistics generator.
- * Copyright 2001 - 2010 Magnus Loef (Magnus-swe) <magnus-swe@telia.com>
+ * Copyright 2001 - 2011 Magnus Loef <magnus-swe@telia.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -208,10 +208,10 @@ main(int argc, char *argv[])
     while(fgets(old_buffer, conf_size, fp)!=NULL)
     {
 	if( strlen(old_buffer) > 8000 )
-	  continue;
+	    continue;
 
 	if( strstr(old_buffer, "<Anonymous /") )
-	max_rows++;
+	    max_rows++;
 
 	if( strstr(old_buffer, "<VirtualHost") )
 	  found_virtualhost = 1;
@@ -221,12 +221,12 @@ main(int argc, char *argv[])
 	{
 	    if( strstr(old_buffer, "ServerName") )
 	    {
-		snprintf(server_name, *old_buffer, old_buffer+11);
+		snprintf(server_name, 8000, "%s", old_buffer+11);
 		server_name[strlen(server_name)-1]='\0';
 	    }
 	    if( strstr(old_buffer, "ServerIdent on") )
 	    {
-		snprintf(server_name, *old_buffer, old_buffer+15);
+		snprintf(server_name, 8000, "%s", old_buffer+15);
 		server_name[strlen(server_name)-1]='\0';
 	    }
 	}
