@@ -1,5 +1,5 @@
 /* GADMIN-PROFTPD - An easy to use GTK+ frontend for the ProFTPD standalone server.
- * Copyright (C) 2001 - 2010 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2001 - 2011 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -126,7 +126,7 @@ void add_import_users(GtkTreeModel *model, GtkTreePath *path,
     if( strstr((char *)global_server_type, "Virtualhost") )
       sprintf(address_buffer, "<VirtualHost %s>\n", global_server_address);
     else
-      sprintf(address_buffer, global_server_address);
+      sprintf(address_buffer, "%s", global_server_address);
      
     sprintf(port_buffer, "Port %s\n", global_server_port);
 
@@ -440,7 +440,7 @@ void import_button_clicked(GtkButton *button, struct w *widgets)
     g_home_dir = gtk_entry_get_text(GTK_ENTRY(widgets->import_home_entry));
 
     if( strlen(g_home_dir) <= 4000 )
-      sprintf(import_root_dir, g_home_dir);
+      sprintf(import_root_dir, "%s", g_home_dir);
     else
       {
 	 info = g_strdup_printf(_("Error: Home directory too long: %s\n"), g_home_dir);
